@@ -380,6 +380,7 @@ class Dash_app:
         cls.port = port
 
         disabled_btn = False
+        disabled_input = False
         #interval_interval = 5e3
         maxx_interval = -1
 
@@ -397,6 +398,12 @@ class Dash_app:
                               labelStyle={'display': 'inline-block'}
                               ),
                 html.Button('Refresh', id='btn-nclicks-4', n_clicks=0),
+                dcc.Input(
+                    id="input_time",
+                    type='number',
+                    placeholder="Interval, ms",
+                    min=800,
+                ),
                 dcc.Graph(id="heatmap", figure=cls.fig),
                 dcc.Interval(id="animateInterval", interval=cls.interval, n_intervals=0,
                              max_intervals=maxx_interval),
@@ -406,23 +413,28 @@ class Dash_app:
         @app.callback(
             Output("heatmap", "figure"),
             Output("animateInterval", "max_intervals"),
+            Output("animateInterval", "interval"),
             Output('btn-nclicks-4', 'disabled'),
+            Output('input_time', 'disabled'),
             Input('btn-nclicks-1', 'n_clicks'),
             Input('btn-nclicks-2', 'n_clicks'),
             Input('btn-nclicks-3', 'n_clicks'),
             Input('btn-nclicks-5', 'n_clicks'),
             Input('checkbox', 'value'),
             Input('btn-nclicks-4', 'n_clicks'),
+            Input('input_time', 'value'),
             Input("animateInterval", "n_intervals"),
         )
-        def doUpdate(btn1, btn2, btn3, btn5, chkbx, btn4, i):
+        def doUpdate(btn1, btn2, btn3, btn5, chkbx, btn4, time_val, i):
 
             if chkbx[-1] == 'NO':
                 maxx_interval = 0
                 disabled_btn = False
+                disabled_input = False
             else:
                 maxx_interval = -1
                 disabled_btn = True
+                disabled_input = True
 
             changed_id = [p['prop_id'] for p in callback_context.triggered][0]
             if 'btn-nclicks-1' in changed_id:
@@ -439,8 +451,11 @@ class Dash_app:
                 fig.update_traces(z=z)
             else:
                 pass
+            if time_val:
+                cls.interval = time_val
+
             z = data.njit_result
 
-            return cls.fig.update_traces(z=z), maxx_interval, disabled_btn
+            return cls.fig.update_traces(z=z), maxx_interval, cls.interval, disabled_btn, disabled_input
 
         return app.run_server(mode=cls.mode, port=cls.port)
